@@ -177,10 +177,7 @@ class Whups_Api extends Horde_Registry_Api
 
         // More checks if we're assigning the ticket at create-time.
         if ($GLOBALS['registry']->getAuth() && $whups_driver->isCategory('assigned', $vars->get('state'))) {
-            $form4 = new Whups_Form_Ticket_CreateStep4Form($vars);
-        }
-        if ($GLOBALS['registry']->getAuth() && $whups_driver->isCategory('assigned', $vars->get('state'))) {
-            $form4 = new Whups_Form_Ticket_CreateStep4Form($vars);
+            $form4 = new Whups_Form_Ticket_CreateStepFour($vars);
             $form4->useToken(false);
             if (!$form4->validate($vars, true)) {
                 throw new Whups_Exception('Invalid arguments (' . var_export($form4->getErrors(), true) . ')');
@@ -218,7 +215,7 @@ class Whups_Api extends Horde_Registry_Api
 
         // Populate $vars with existing ticket details.
         $vars = new Horde_Variables();
-        $ticket->setDetails($vars);
+        $ticket->setDetails($vars, true);
 
         // Copy new ticket details in.
         foreach ($ticket_info as $detail => $newval) {
@@ -242,6 +239,7 @@ class Whups_Api extends Horde_Registry_Api
 
         $ticket->change('summary', $info['summary']);
         $ticket->change('state', $info['state']);
+        $ticket->change('due', $info['due']);
         $ticket->change('priority', $info['priority']);
         if (!empty($info['newcomment'])) {
             $ticket->change('comment', $info['newcomment']);
@@ -397,7 +395,6 @@ class Whups_Api extends Horde_Registry_Api
                     'name'              => '[' . _("Ticket") . ' #' . $ticket['id'] . '] ' . $ticket['summary'],
                     'desc'              => null,
                     'due'               => null,
-                    'category'          => null,
                     'view_link'         => $view_link,
                     'delete_link'       => $delete_link,
                     'edit_link'         => $view_link,
