@@ -1,7 +1,7 @@
 <?php
 /**
  * Copyright 2001-2002 Robert E. Coyle <robertecoyle@hotmail.com>
- * Copyright 2001-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2001-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (BSD). If you
  * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
@@ -391,7 +391,7 @@ class Whups
         try {
             return Whups_Ticket::makeTicket($id);
         } catch (Whups_Exception $e) {
-            if ($ticket->code === 0) {
+            if ($e->code === 0) {
                 // No permissions to this ticket.
                 $GLOBALS['notification']->push($e->getMessage(), 'horde.warning');
                 $default->redirect();
@@ -405,7 +405,8 @@ class Whups
     /**
      * Adds topbar search to page
      */
-    static public function addTopbarSearch() {
+    static public function addTopbarSearch()
+    {
         $topbar = $GLOBALS['injector']->getInstance('Horde_View_Topbar');
         $topbar->search = true;
         $topbar->searchAction = Horde::url('ticket');
@@ -1061,7 +1062,7 @@ class Whups
                     array(
                         'file' => $file['name'],
                         'id' => $ticket,
-                        'url' => Horde::selfUrl(true, false, true)
+                        'url' => Horde::signUrl(Horde::selfUrl(true, false, true))
                     )
                 )
                 ->link(array(
@@ -1130,8 +1131,10 @@ class Whups
         $classes = get_declared_classes();
 
         /* Filter for the Horde_Form_Type classes. */
-        $blacklist = array('invalid', 'addresslink', 'spacer', 'description',
-                           'captcha', 'figlet', 'header');
+        $blacklist = array(
+            'addresslink', 'captcha', 'description', 'figlet', 'header',
+            'image', 'invalid', 'spacer'
+        );
         foreach ($classes as $class) {
             if (stripos($class, 'horde_form_type_') !== false) {
                 $field_type = substr($class, 16);
