@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2002-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2002-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (BSD). If you
  * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
@@ -23,8 +23,8 @@ $layout->handle(Horde_Util::getFormData('action'),
                 (int)Horde_Util::getFormData('col'));
 if ($layout->updated()) {
     $prefs->setValue('mybugs_layout', $layout->serialize());
-    if (Horde_Util::getFormData('url')) {
-        $url = new Horde_Url(Horde_Util::getFormData('url'));
+    if ($url = Horde::verifySignedUrl(Horde_Util::getFormData('url'))) {
+        $url = new Horde_Url($url);
         $url->unique()->redirect();
     }
 }
