@@ -3,7 +3,7 @@
  * Displays and handles the form to delete an attachment from the ticket.
  *
  * Copyright 2001-2002 Robert E. Coyle <robertecoyle@hotmail.com>
- * Copyright 2001-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2001-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (BSD). If you
  * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
@@ -28,7 +28,7 @@ try {
     $notification->push($e, 'horde.error');
 }
 
-if ($url = Horde_Util::getFormData('url')) {
+if ($url = Horde::verifySignedUrl(Horde_Util::getFormData('url'))) {
     header('Location: ' . $url);
 } else {
     Horde::url($prefs->getValue('whups_default_view') . '.php', true)
