@@ -2,7 +2,7 @@
 /**
  * Deletes a history entry from the ticket.
  *
- * Copyright 2010-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2010-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (BSD). If you
  * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
@@ -26,7 +26,7 @@ try {
     $notification->push($e, 'horde.error');
 }
 
-if ($url = Horde_Util::getFormData('url')) {
+if ($url = Horde::verifySignedUrl(Horde_Util::getFormData('url'))) {
     header('Location: ' . $url);
 } else {
     Horde::url($prefs->getValue('whups_default_view') . '.php', true)
